.. -*- mode: rst -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:

.. _chap_modref:

***********************
Python module reference
***********************

This module reference extends the manual with a comprehensive overview of the
available functionality.  Each module in the package is documented by a general
summary of its purpose and the list of classes and functions it provides.

Commands
========

.. currentmodule:: datalad_crawler
.. autosummary::
     :toctree: generated

     crawl
     crawl_init

Pipelines
=========

.. currentmodule:: datalad_crawler
.. autosummary::
     :toctree: generated

     pipeline
